@@ -516,7 +516,7 @@ void Dialog_Layout_Details::on_button_down()
 void Dialog_Layout_Details::on_button_add_field()
 {
   type_list_field_items fields_list = offer_field_list(m_table_name, this);
-  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); iter_chosen++) 
+  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); ++iter_chosen) 
   {
     sharedptr<LayoutItem_Field> layout_item = *iter_chosen;
     if(!layout_item)
@@ -944,7 +944,7 @@ void Dialog_Layout_Details::on_button_field_formatting()
       sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
       if(field)
       {
-        sharedptr<LayoutItem_Field> chosenitem = offer_field_formatting(field, m_table_name, this);
+        sharedptr<LayoutItem_Field> chosenitem = offer_field_formatting(field, get_fields_table(), this);
         if(chosenitem)
         {
           *field = *chosenitem; //TODO_Performance.
@@ -1428,6 +1428,12 @@ void Dialog_Layout_Details::on_treeview_cell_edited_group_columns(const Glib::us
   }
 }
 
+
+Glib::ustring Dialog_Layout_Details::get_fields_table() const
+{
+  return m_table_name;
+}
+
 } //namespace Glom
 
 
